@@ -1,6 +1,6 @@
 package Bundle::Interchange;
 
-$VERSION = '1.07';
+$VERSION = '1.08';
 
 1;
 
@@ -32,14 +32,14 @@ HTML::Tagset
 
 HTML::Entities
 
-Bundle::LWP
+LWP
+
+LWP::Protocol::https
 
 Parse::RecDescent
 
 OLE::Storage_Lite
 
-Bundle::LWP
-
 Term::ReadKey
 
 Term::ReadLine::Perl
